
.. _catkeys:

Haiku catkeys
*************

.. versionadded:: 1.8

Localisation for the `Haiku <http://www.haiku-os.org/>`_ operating system is
done with a file format called catkeys.  It is a bilingual file format.

.. _catkeys#links:

Links
=====

* `Some notes about the format
  <http://www.haiku-os.org/blog/pulkomandy/2009-09-24_haiku_locale_kit_translator_handbook>`_
* `Some example files
  <http://cgit.haiku-os.org/haiku/tree/data/catalogs/>`_
